@@ -331,7 +331,7 @@ class PlaceService(BaseRdbmsService):
         # improve a lot the performance (milliseconds v.s. a few seconds).
         areas = AreaService().find_areas_with_location(
             location,
-            lowest_area_level=min(AREA_LEVEL_DISTRICT, area_level),
+            lowest_area_level=max(AREA_LEVEL_DISTRICT, area_level),
             highest_area_level=area_level,
             locale=locale)
 
@@ -794,20 +794,22 @@ class PlaceService(BaseRdbmsService):
         with self.acquire_rdbms_connection(auto_commit=True, connection=connection) as connection:
             cursor = connection.execute(
                 """
-                INSERT INTO place(
+                INSERT INTO place (
                     account_id,
                     category,
                     location,
                     boundaries,
                     is_address_edited,
-                    is_location_edited)
-                  VALUES 
-                    (%(account_id)s,
-                     %(category)s,
-                     ST_SetSRID(ST_MakePoint(%(longitude)s, %(latitude)s, %(altitude)s), 4326),
-                     ST_MakePolygon(ST_GeomFromText(%(boundaries)s, 4326)),                     
-                     %(is_address_edited)s,
-                     %(is_location_edited)s)
+                    is_location_edited
+                  )
+                  VALUES (
+                    %(account_id)s,
+                    %(category)s,
+                    ST_SetSRID(ST_MakePoint(%(longitude)s, %(latitude)s, %(altitude)s), 4326),
+                    ST_MakePolygon(ST_GeomFromText(%(boundaries)s, 4326)),                     
+                    %(is_address_edited)s,
+                    %(is_location_edited)s
+                  )
                   RETURNING 
                     object_status,
                     place_id,
@@ -818,7 +820,8 @@ class PlaceService(BaseRdbmsService):
                     'altitude': (location and location.altitude) or 0,
                     'boundaries': boundaries and 'LINESTRING(%s)' % ','.join([
                         f'{longitude} {latitude} {altitude}'
-                        for longitude, latitude, altitude in boundaries]),
+                        for longitude, latitude, altitude in boundaries
+                    ]),
                     'category': category,  # @todo: `category.strip().lower()` when category won't be a enumeration anymore
                     'is_address_edited': is_address_edited,
                     'is_location_edited': is_location_edited,
